==> quarkus-bootstrap-core-1.7.0.Final-sources.jar: io/quarkus/bootstrap/utils/BuildToolHelper.java <==
package io.quarkus.bootstrap.utils;

import static io.quarkus.bootstrap.util.QuarkusModelHelper.DEVMODE_REQUIRED_TASKS;

import io.quarkus.bootstrap.resolver.AppModelResolverException;
import io.quarkus.bootstrap.resolver.QuarkusGradleModelFactory;
import io.quarkus.bootstrap.resolver.model.QuarkusModel;
import io.quarkus.bootstrap.util.QuarkusModelHelper;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;

/**
 * Helper class used to expose build tool used by the project
 */
public class BuildToolHelper {

    public enum BuildTool {
        MAVEN("pom.xml"),
        GRADLE("build.gradle");

        private final String buildFile;

        BuildTool(String buildFile) {
            this.buildFile = buildFile;
        }

        public String getBuildFile() {
            return buildFile;
        }
    }

    private BuildToolHelper() {

    }

    public static boolean isMavenProject(Path project) {
        Path currentPath = project;
        while (currentPath != null) {
            if (Files.exists(currentPath.resolve(BuildTool.MAVEN.getBuildFile()))) {
                return true;
            }
            if (Files.exists(currentPath.resolve(BuildTool.GRADLE.getBuildFile()))) {
                return false;
            }
            currentPath = currentPath.getParent();
        }
        return false;
    }

    public static Path getBuildFile(Path project, BuildTool tool) {
        Path currentPath = project;
        while (currentPath != null) {
            if (Files.exists(currentPath.resolve(tool.getBuildFile()))) {
                return currentPath;
            }
            currentPath = currentPath.getParent();
        }
        return null;
    }

    public static QuarkusModel enableGradleAppModel(Path projectRoot, String mode)
            throws IOException, AppModelResolverException {
        if (isMavenProject(projectRoot)) {
            return null;
        }
        final QuarkusModel model = QuarkusGradleModelFactory.create(getBuildFile(projectRoot, BuildTool.GRADLE).toFile(),
                mode);
        QuarkusModelHelper.exportModel(model);
        return model;
    }

    public static QuarkusModel enableGradleAppModelForDevMode(Path projectRoot) throws IOException, AppModelResolverException {
        if (isMavenProject(projectRoot)) {
            return null;
        }
        final QuarkusModel model = QuarkusGradleModelFactory
                .createForTasks(getBuildFile(projectRoot, BuildTool.GRADLE).toFile(), DEVMODE_REQUIRED_TASKS);
        QuarkusModelHelper.exportModel(model);
        return model;
    }

}

==> quarkus-bootstrap-core-1.9.0.Final-sources.jar: io/quarkus/bootstrap/utils/BuildToolHelper.java <==
package io.quarkus.bootstrap.utils;

import static io.quarkus.bootstrap.util.QuarkusModelHelper.DEVMODE_REQUIRED_TASKS;
import static io.quarkus.bootstrap.util.QuarkusModelHelper.ENABLE_JAR_PACKAGING;
import static io.quarkus.bootstrap.util.QuarkusModelHelper.TEST_REQUIRED_TASKS;

import io.quarkus.bootstrap.resolver.AppModelResolverException;
import io.quarkus.bootstrap.resolver.QuarkusGradleModelFactory;
import io.quarkus.bootstrap.resolver.model.QuarkusModel;
import io.quarkus.bootstrap.util.QuarkusModelHelper;
import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.List;

/**
 * Helper class used to expose build tool used by the project
 */
public class BuildToolHelper {

    public enum BuildTool {
        MAVEN("pom.xml"),
        GRADLE("build.gradle", "build.gradle.kts");

        private final String[] buildFiles;

        BuildTool(String... buildFile) {
            this.buildFiles = buildFile;
        }

        public String[] getBuildFiles() {
            return buildFiles;
        }

        public boolean exists(Path root) {
            for (String buildFile : buildFiles) {
                if (Files.exists(root.resolve(buildFile))) {
                    return true;
                }
            }
            return false;
        }
    }

    private BuildToolHelper() {

    }

    public static boolean isMavenProject(Path project) {
        Path currentPath = project;
        while (currentPath != null) {
            if (BuildTool.MAVEN.exists(currentPath)) {
                return true;
            }
            if (BuildTool.GRADLE.exists(currentPath)) {
                return false;
            }
            currentPath = currentPath.getParent();
        }
        return false;
    }

    public static boolean isGradleProject(Path project) {
        Path currentPath = project;
        while (currentPath != null) {
            if (BuildTool.MAVEN.exists(currentPath)) {
                return false;
            }
            if (BuildTool.GRADLE.exists(currentPath)) {
                return true;
            }
            currentPath = currentPath.getParent();
        }
        return false;
    }

    public static Path getBuildFile(Path project, BuildTool tool) {
        Path currentPath = project;
        while (currentPath != null) {
            if (tool.exists(currentPath)) {
                return currentPath;
            }
            currentPath = currentPath.getParent();
        }
        return null;
    }

    public static QuarkusModel enableGradleAppModelForTest(Path projectRoot) throws IOException, AppModelResolverException {
        // We enable jar packaging since we want test-fixtures as jars
        return enableGradleAppModel(projectRoot, "TEST", ENABLE_JAR_PACKAGING, TEST_REQUIRED_TASKS);
    }

    public static QuarkusModel enableGradleAppModel(Path projectRoot, String mode, List<String> jvmArgs, String... tasks)
            throws IOException, AppModelResolverException {
        if (isMavenProject(projectRoot)) {
            return null;
        }
        final QuarkusModel model = QuarkusGradleModelFactory.create(getBuildFile(projectRoot, BuildTool.GRADLE).toFile(),
                mode, jvmArgs, tasks);
        QuarkusModelHelper.exportModel(model);
        return model;
    }

    public static QuarkusModel enableGradleAppModelForDevMode(Path projectRoot) throws IOException, AppModelResolverException {
        if (isMavenProject(projectRoot)) {
            return null;
        }
        final QuarkusModel model = QuarkusGradleModelFactory
                .createForTasks(getBuildFile(projectRoot, BuildTool.GRADLE).toFile(), DEVMODE_REQUIRED_TASKS);
        QuarkusModelHelper.exportModel(model);
        return model;
    }

}
